@@ -1,15 +1,41 @@
 import copy
 import inspect
 import json
+import sys
 import typing
 from base64 import b64encode
 from collections.abc import AsyncGenerator, Generator
-from types import FunctionType
 
-from rpcpy.asgi import EventResponse as AsgiEventResponse
-from rpcpy.asgi import Request as AsgiRequest
-from rpcpy.asgi import Response as AsgiResponse
+if sys.version_info[:2] < (3, 8):
+    from typing_extensions import Literal, TypedDict
+else:
+    from typing import Literal, TypedDict
+
+from baize.asgi import PlainTextResponse as AsgiResponse
+from baize.asgi import Request as AsgiRequest
+from baize.asgi import SendEventResponse as AsgiEventResponse
+from baize.typing import (
+    ASGIApp,
+    Environ,
+    Receive,
+    Scope,
+    Send,
+    ServerSentEvent,
+    StartResponse,
+    WSGIApp,
+)
+from baize.wsgi import PlainTextResponse as WsgiResponse
+from baize.wsgi import Request as WsgiRequest
+from baize.wsgi import SendEventResponse as WsgiEventResponse
+
 from rpcpy.exceptions import SerializerNotFound
+from rpcpy.openapi import TEMPLATE as OPENAPI_TEMPLATE
+from rpcpy.openapi import (
+    create_model,
+    is_typed_dict_type,
+    parse_typed_dict,
+    set_type_model,
+)
 from rpcpy.serializers import (
     SERIALIZER_NAMES,
     SERIALIZER_TYPES,
@@ -17,29 +43,10 @@ from rpcpy.serializers import (
     JSONSerializer,
     get_serializer,
 )
-from rpcpy.typing import (
-    Environ,
-    Literal,
-    Receive,
-    Scope,
-    Send,
-    StartResponse,
-    TypedDict,
-)
-from rpcpy.utils.openapi import TEMPLATE as OPENAPI_TEMPLATE
-from rpcpy.utils.openapi import (
-    create_model,
-    is_typed_dict_type,
-    parse_typed_dict,
-    set_type_model,
-)
-from rpcpy.wsgi import EventResponse as WsgiEventResponse
-from rpcpy.wsgi import Request as WsgiRequest
-from rpcpy.wsgi import Response as WsgiResponse
 
 __all__ = ["RPC", "WsgiRPC", "AsgiRPC"]
 
-Function = typing.TypeVar("Function", bound=FunctionType)
+Callable = typing.TypeVar("Callable", bound=typing.Callable)
 
 
 class RPCMeta(type):
@@ -75,7 +82,7 @@ class RPC(metaclass=RPCMeta):
         self.response_serializer = response_serializer
         self.openapi = openapi
 
-    def register(self, func: Function) -> Function:
+    def register(self, func: Callable) -> Callable:
         self.callbacks[func.__name__] = func
         set_type_model(func)
         return func
@@ -149,6 +156,8 @@ class RPC(metaclass=RPCMeta):
                     return_annotation = return_annotation.__args__[0]
                 if is_typed_dict_type(return_annotation):
                     resp_model = parse_typed_dict(return_annotation)
+                elif return_annotation is None:
+                    resp_model = create_model(callback.__name__ + "-return")
                 else:
                     resp_model = create_model(
                         callback.__name__ + "-return",
@@ -212,7 +221,7 @@ class RPC(metaclass=RPCMeta):
 
         # check request method
         if request.method != "POST":
-            return self.return_response_class(request)(status_code=405)
+            return self.return_response_class(request)(b"", status_code=405)
 
         # check serializer
         try:
@@ -224,19 +233,25 @@ class RPC(metaclass=RPCMeta):
 
 
 class WsgiRPC(RPC):
-    def register(self, func: Function) -> Function:
+    def register(self, func: Callable) -> Callable:
         if inspect.iscoroutinefunction(func) or inspect.isasyncgenfunction(func):
             raise TypeError("WSGI mode can only register synchronization functions.")
         return super().register(func)
 
     def create_generator(
         self, generator: typing.Generator
-    ) -> typing.Generator[str, None, None]:
+    ) -> typing.Generator[ServerSentEvent, None, None]:
         for data in generator:
-            yield b64encode(self.response_serializer.encode(data)).decode("ascii")
+            yield {
+                "data": b64encode(self.response_serializer.encode(data)).decode("ascii")
+            }
 
-    def on_call(self, request: WsgiRequest) -> WsgiResponse:
-        data = self.request_serializer.decode(request.body)
+    def on_call(self, request: WsgiRequest) -> WSGIApp:
+        body = request.body
+        if not body:
+            data = {}
+        else:
+            data = self.request_serializer.decode(body)
 
         callback = self.callbacks[request.url.path[len(self.prefix) :]]
         if hasattr(callback, "__body_model__"):
@@ -244,8 +259,9 @@ class WsgiRPC(RPC):
         else:
             result = callback(**data)
 
+        response: typing.Union[WsgiEventResponse, WsgiResponse]
         if inspect.isgenerator(result):
-            response: WsgiResponse = WsgiEventResponse(
+            response = WsgiEventResponse(
                 self.create_generator(result), headers={"serializer-base": "base64"}
             )
         else:
@@ -265,19 +281,25 @@ class WsgiRPC(RPC):
 
 
 class AsgiRPC(RPC):
-    def register(self, func: Function) -> Function:
+    def register(self, func: Callable) -> Callable:
         if not (inspect.iscoroutinefunction(func) or inspect.isasyncgenfunction(func)):
             raise TypeError("ASGI mode can only register asynchronous functions.")
         return super().register(func)
 
     async def create_generator(
         self, generator: typing.AsyncGenerator
-    ) -> typing.AsyncGenerator[str, None]:
+    ) -> typing.AsyncGenerator[ServerSentEvent, None]:
         async for data in generator:
-            yield b64encode(self.response_serializer.encode(data)).decode("ascii")
+            yield {
+                "data": b64encode(self.response_serializer.encode(data)).decode("ascii")
+            }
 
-    async def on_call(self, request: AsgiRequest) -> AsgiResponse:
-        data = self.request_serializer.decode(await request.body)
+    async def on_call(self, request: AsgiRequest) -> ASGIApp:
+        body = await request.body
+        if not body:
+            data = {}
+        else:
+            data = self.request_serializer.decode(body)
 
         callback = self.callbacks[request.url.path[len(self.prefix) :]]
         if hasattr(callback, "__body_model__"):
@@ -285,8 +307,9 @@ class AsgiRPC(RPC):
         else:
             result = callback(**data)
 
+        response: typing.Union[AsgiEventResponse, AsgiResponse]
         if inspect.isasyncgen(result):
-            response: AsgiResponse = AsgiEventResponse(
+            response = AsgiEventResponse(
                 self.create_generator(result), headers={"serializer-base": "base64"}
             )
         else:
