@@ -2,16 +2,15 @@ import functools
 import inspect
 import typing
 from base64 import b64decode
-from types import FunctionType
 
 import httpx
 
+from rpcpy.openapi import validate_arguments
 from rpcpy.serializers import BaseSerializer, JSONSerializer, get_serializer
-from rpcpy.utils.openapi import validate_arguments
 
 __all__ = ["Client"]
 
-Function = typing.TypeVar("Function", bound=FunctionType)
+Callable = typing.TypeVar("Callable", bound=typing.Callable)
 
 
 class ClientMeta(type):
@@ -43,10 +42,10 @@ class Client(metaclass=ClientMeta):
         self.client = client
         self.request_serializer = request_serializer
 
-    def remote_call(self, func: Function) -> Function:
+    def remote_call(self, func: Callable) -> Callable:
         return func
 
-    def _get_url(self, func: Function) -> str:
+    def _get_url(self, func: Callable) -> str:
         return self.base_url + func.__name__
 
     def _get_content(
@@ -54,14 +53,18 @@ class Client(metaclass=ClientMeta):
     ) -> bytes:
         sig = inspect.signature(func)
         bound_values = sig.bind(*args, **kwargs)
-        return self.request_serializer.encode(dict(**bound_values.arguments))
+        parameters = dict(**bound_values.arguments)
+        if parameters:
+            return self.request_serializer.encode(parameters)
+        else:
+            return b""
 
 
 class AsyncClient(Client):
     if typing.TYPE_CHECKING:
         client: httpx.AsyncClient
 
-    def remote_call(self, func: Function) -> Function:
+    def remote_call(self, func: Callable) -> Callable:
         if not (inspect.iscoroutinefunction(func) or inspect.isasyncgenfunction(func)):
             raise TypeError(
                 "Asynchronous Client can only register asynchronous functions."
@@ -111,14 +114,14 @@ class AsyncClient(Client):
                             b64decode(data.encode("ascii"))
                         )
 
-        return typing.cast(Function, wrapper)
+        return typing.cast(Callable, wrapper)
 
 
 class SyncClient(Client):
     if typing.TYPE_CHECKING:
         client: httpx.Client
 
-    def remote_call(self, func: Function) -> Function:
+    def remote_call(self, func: Callable) -> Callable:
         if inspect.iscoroutinefunction(func) or inspect.isasyncgenfunction(func):
             raise TypeError(
                 "Synchronization Client can only register synchronization functions."
@@ -168,4 +171,4 @@ class SyncClient(Client):
                             b64decode(data.encode("ascii"))
                         )
 
-        return typing.cast(Function, wrapper)
+        return typing.cast(Callable, wrapper)
