@@ -8,6 +8,11 @@ try:
 except ImportError:  # pragma: no cover
     msgpack = None  # type: ignore
 
+try:
+    import cbor2 as cbor
+except ImportError:  # pragma: no cover
+    cbor = None  # type: ignore
+
 from rpcpy.exceptions import SerializerNotFound
 
 
@@ -88,16 +93,33 @@ class MsgpackSerializer(BaseSerializer):
         return msgpack.unpackb(data, object_hook=self.default_decode)
 
 
+class CBORSerializer(BaseSerializer):
+    """
+    CBOR: https://tools.ietf.org/html/rfc7049
+    """
+
+    name = "cbor"
+    content_type = "application/x-cbor"
+
+    def encode(self, data: typing.Any) -> bytes:
+        return cbor.dumps(data)
+
+    def decode(self, data: bytes) -> typing.Any:
+        return cbor.loads(data)
+
+
 SERIALIZER_NAMES = {
     JSONSerializer.name: JSONSerializer(),
     PickleSerializer.name: PickleSerializer(),
     MsgpackSerializer.name: MsgpackSerializer(),
+    CBORSerializer.name: CBORSerializer(),
 }
 
 SERIALIZER_TYPES = {
     JSONSerializer.content_type: JSONSerializer(),
     PickleSerializer.content_type: PickleSerializer(),
     MsgpackSerializer.content_type: MsgpackSerializer(),
+    CBORSerializer.content_type: CBORSerializer(),
 }
 
 
